@@ -1,7 +1,9 @@
 //! 连接模块，包括 http client 和 websocket （直播间）连接
 //!
+#[cfg(feature = "live")]
 use futures::{stream::SplitStream, FutureExt, Stream, StreamExt};
 use reqwest::Client;
+#[cfg(feature = "live")]
 use std::{
     collections::VecDeque,
     future::Future,
@@ -9,19 +11,27 @@ use std::{
     task::{Context, Poll},
 };
 
+#[cfg(feature = "live")]
 type WebSocketStream = async_tungstenite::WebSocketStream<async_tungstenite::tokio::ConnectStream>;
+#[cfg(feature = "live")]
 use async_tungstenite::tungstenite::Error as WsError;
 
+#[cfg(feature = "live")]
 use crate::ws_protocol;
+#[cfg(feature = "live")]
 type WsResult<T> = Result<T, WsError>;
 
 /// 创建一个新的 http 连接
 pub fn new_client() -> reqwest::Result<Client> {
     const USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION"));
     trace!("user agent name: {}", USER_AGENT);
-    Client::builder().user_agent(USER_AGENT).build()
+    Client::builder()
+        .user_agent(USER_AGENT)
+        .cookie_store(true)
+        .build()
 }
 
+#[cfg(feature = "live")]
 /// 直播间 websocket 连接，实现了 [`Stream`][`futures::Stream`]
 ///
 /// # Example
@@ -43,6 +53,7 @@ pub struct LiveConnection {
     read: SplitStream<WebSocketStream>,
     buffered_msg: VecDeque<ws_protocol::Packet>,
 }
+#[cfg(feature = "live")]
 impl LiveConnection {
     /// 从 url 建立一个新连接，需要 room_id 和 token，这些数据可以从
     /// [`InfoByRoom`][`crate::requests::InfoByRoom`] 拿到
@@ -59,7 +70,13 @@ impl LiveConnection {
             loop {
                 tokio::time::sleep(std::time::Duration::from_secs(30)).await;
                 debug!("sending heartbeat...");
-                write.send(ws_protocol::Packet::heartbeat().into()).await?;
+                write
+                    .send(ws_protocol::Packet::heartbeat().into())
+                    .await
+                    .map_err(|e| {
+                        debug!("failed to send heartbeat: {:?}", e);
+                        e
+                    })?;
             }
         });
         Ok(Self {
@@ -70,6 +87,7 @@ impl LiveConnection {
         })
     }
 }
+#[cfg(feature = "live")]
 impl Stream for LiveConnection {
     type Item = crate::Result<ws_protocol::Packet>;
     fn poll_next(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
